aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/SkPathMeasure.cpp
diff options
context:
space:
mode:
authorGravatar halcanary <halcanary@google.com>2015-08-27 07:41:13 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-08-27 07:41:16 -0700
commit96fcdcc219d2a0d3579719b84b28bede76efba64 (patch)
tree0ec5ea0193d8292df8bf5ed9dd8498a5eb5763dd /src/core/SkPathMeasure.cpp
parent435af2f736c85c3274a0c6760a3523810750d237 (diff)
Style Change: NULL->nullptr
Diffstat (limited to 'src/core/SkPathMeasure.cpp')
-rw-r--r--src/core/SkPathMeasure.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/core/SkPathMeasure.cpp b/src/core/SkPathMeasure.cpp
index 17ae95e801..caff6df399 100644
--- a/src/core/SkPathMeasure.cpp
+++ b/src/core/SkPathMeasure.cpp
@@ -297,7 +297,7 @@ static void compute_pos_tan(const SkPoint pts[], int segType,
}
} break;
case kCubic_SegType:
- SkEvalCubicAt(pts, t, pos, tangent, NULL);
+ SkEvalCubicAt(pts, t, pos, tangent, nullptr);
if (tangent) {
tangent->normalize();
}
@@ -402,7 +402,7 @@ static void seg_to(const SkPoint pts[], int segType,
////////////////////////////////////////////////////////////////////////////////
SkPathMeasure::SkPathMeasure() {
- fPath = NULL;
+ fPath = nullptr;
fLength = -1; // signal we need to compute it
fForceClosed = false;
fFirstPtIndex = -1;
@@ -435,7 +435,7 @@ void SkPathMeasure::setPath(const SkPath* path, bool forceClosed) {
}
SkScalar SkPathMeasure::getLength() {
- if (fPath == NULL) {
+ if (fPath == nullptr) {
return 0;
}
if (fLength < 0) {
@@ -452,7 +452,7 @@ int SkTKSearch(const T base[], int count, const K& key) {
return ~0;
}
- SkASSERT(base != NULL); // base may be NULL if count is zero
+ SkASSERT(base != nullptr); // base may be nullptr if count is zero
int lo = 0;
int hi = count - 1;
@@ -511,7 +511,7 @@ const SkPathMeasure::Segment* SkPathMeasure::distanceToSegment(
bool SkPathMeasure::getPosTan(SkScalar distance, SkPoint* pos,
SkVector* tangent) {
- if (NULL == fPath) {
+ if (nullptr == fPath) {
return false;
}
@@ -538,7 +538,7 @@ bool SkPathMeasure::getPosTan(SkScalar distance, SkPoint* pos,
bool SkPathMeasure::getMatrix(SkScalar distance, SkMatrix* matrix,
MatrixFlags flags) {
- if (NULL == fPath) {
+ if (nullptr == fPath) {
return false;
}
@@ -584,7 +584,7 @@ bool SkPathMeasure::getSegment(SkScalar startD, SkScalar stopD, SkPath* dst,
SkASSERT(seg <= stopSeg);
if (startWithMoveTo) {
- compute_pos_tan(&fPts[seg->fPtIndex], seg->fType, startT, &p, NULL);
+ compute_pos_tan(&fPts[seg->fPtIndex], seg->fType, startT, &p, nullptr);
dst->moveTo(p);
}